==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonDynamoDbAttributes.md <==
# AmazonDynamoDbAttributes


```text
aws-20210730/Resource/Database/AmazonDynamoDbAttributes
```

```text
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')
```



| Illustration | AmazonDynamoDbAttributes | AmazonDynamoDbAttributesCard | AmazonDynamoDbAttributesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributes.png) | ![illustration for AmazonDynamoDbAttributes](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributes.Local.png) | ![illustration for AmazonDynamoDbAttributesCard](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributesCard.Local.png) | ![illustration for AmazonDynamoDbAttributesGroup](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributesGroup.Local.png) |




## AmazonDynamoDbAttributes

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributes
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributes('AmazonDynamoDbAttributes', 'Amazon Dynamo Db Attributes', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributes
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributes('AmazonDynamoDbAttributes', 'Amazon Dynamo Db Attributes', 'an optional tech label')
@enduml
```

## AmazonDynamoDbAttributesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesCard
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesCard('AmazonDynamoDbAttributesCard', 'Amazon Dynamo Db Attributes Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesCard
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesCard('AmazonDynamoDbAttributesCard', 'Amazon Dynamo Db Attributes Card', 'an optional description')
@enduml
```

## AmazonDynamoDbAttributesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesGroup('AmazonDynamoDbAttributesGroup', 'Amazon Dynamo Db Attributes Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesGroup('AmazonDynamoDbAttributesGroup', 'Amazon Dynamo Db Attributes Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonDynamoDbAttributes.md <==
# AmazonDynamoDbAttributes


```text
aws-20210730/Resource/Database/AmazonDynamoDbAttributes
```

```text
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')
```



| Illustration | AmazonDynamoDbAttributes | AmazonDynamoDbAttributesCard | AmazonDynamoDbAttributesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributes.png) | ![illustration for AmazonDynamoDbAttributes](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributes.Local.png) | ![illustration for AmazonDynamoDbAttributesCard](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributesCard.Local.png) | ![illustration for AmazonDynamoDbAttributesGroup](../../../aws-20210730/Resource/Database/AmazonDynamoDbAttributesGroup.Local.png) |




## AmazonDynamoDbAttributes

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributes
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributes('AmazonDynamoDbAttributes', 'Amazon Dynamo Db Attributes', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributes
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributes('AmazonDynamoDbAttributes', 'Amazon Dynamo Db Attributes', 'an optional tech label')
@enduml
```

## AmazonDynamoDbAttributesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesCard
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesCard('AmazonDynamoDbAttributesCard', 'Amazon Dynamo Db Attributes Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesCard
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesCard('AmazonDynamoDbAttributesCard', 'Amazon Dynamo Db Attributes Card', 'an optional description')
@enduml
```

## AmazonDynamoDbAttributesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesGroup('AmazonDynamoDbAttributesGroup', 'Amazon Dynamo Db Attributes Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonDynamoDbAttributesGroup
include('aws-20210730/Resource/Database/AmazonDynamoDbAttributes')

' renders the element
AmazonDynamoDbAttributesGroup('AmazonDynamoDbAttributesGroup', 'Amazon Dynamo Db Attributes Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
